# Other terminology

Lawrence Rosen used the term "eventual source" and says that L. Peter Deutsch
used "eventual licensing" in connection with Ghostscript.

Creative Commons referred to "springing licenses" ("a legal mechanism for
granting a license that automatically springs into life at a future date").
A concrete example which CC proposed (but no longer suggests or operates)
is the "Founders' Copyright", which attempted to make copyrighted works
functionally public domain following a period of 14 or 28 years after
initial publication, inspired by provisions of 1790 U.S. copyright
legislation.

# Things that are DOSP

* Springing licenses that automatically convert after a particular delay (but note that these can convert from proprietary to open source, like BUSL, or from one open source license to another, like BOSL)

* A promise to (explicitly or manually) relicense older versions on a predictable schedule, when this promise is made and complied with

# Things that are adjacent to DOSP

* Bounty and buy-out mechanisms

Many people have proposed bounty mechanisms, or investment structures like
assurance contracts, which would allow a proprietary codebase to be "bought
out" by a community of prospective users (or philanthropists).  In these
scenarios, developers would typically receive a large one-time payment in
exchange for switching an existing codebase from a proprietary to an
open-source licensing model.  There has been considerable theoretical
interest in structures and mechanisms for funding public goods, several
of which assume that creative work will be proprietary by default, either
initially or if a public funding attempt fails.

[note about Blender story]

Buy-out mechanisms are potentially adjacent to DOSP when the public knows
ahead of time that there is a specific path available to convert
particular software's licensing.

* Ted Ts'o's TPL

In 2003, Ted Ts'o proposed a license which lets recipients redistribute
derived works under BSD-like terms for a specified period of time, and
which then later automatically imposes a GPL-like obligation on them
after a delay.  He suggests that this is a compromise between benefits
of permissive and reciprocal licensing models.  This is framed as allowing
downstream developers (not the original licensor) to temporarily, but not
permanently, publish their modified versions under proprietary licensing
terms.

This seems to be the same concept as the Transitive Grace Period Public
License (TGPPL), which (for example in
https://tahoe-lafs.org/~zooko/tgppl.pdf) was described as a time-based
compromise between GPL and BSD licensing models.  TGPPL later became
the Bootstrap Open Source License (BOSL).

It's important to note that this is focused on temporarily granting
(immediate) recipients of code rights intermediate between those of BSD
and GPL models, as distinct from BUSL, which temporarily grants everyone
reduced rights relative to open sources.  The TPL, TGPPL, and BOSL models
focus on economic incentives of downstream software development using
a code base, while the BUSL focuses on economic incentives of the upstream
developer itself.

(As a result, BOSL claims to already be an open source license -- as
recipients of the original code already receive full rights that comply
with the Open Source Definition -- while BUSL does not claim to be an
open source license.)

* Springing licenses that trigger in some way other than a fixed time delay

We have at least one example of an anti-abandonware license that states
that the license will convert to a specified open source liense under
conditions indicating that the upstream developer has ceased development
or has ceased operating.

* An informal habit of releasing older software as open source after its
  presumed period of commercial viability

This is seen with id Games and some other game developers, as well as
historic versions of some major proprietary operating systems.  This may
be habitual on the developers' part or a response to outside community
requests, but it is not concretely pre-planned or pre-announced, and
there is no way for the public to rely on it or guarantee that a particular
organization's relicensing practice will continue.

See also

https://en.wikipedia.org/wiki/List_of_commercial_video_games_with_later_released_source_code

(collecting examples of this practice); as noted there, the work as
whole is often not actually relicensed as open source (as "artwork and
data are often released under a different license than the source code").

* Initial proprietary publication for mainly non-economic reasons, with an open-ended pledge to adopt an open source license in the future

Several projects have been published initially under a proprietary license
for reasons such as embarrassment over code quality, doubts about code
security, or a desire to wait until a governance or funding structure has
been selected and implemented.  Their developers have stated unequivocally
that they prefer and intend to eventually make the projects open source,
but this statement may not offer any concrete schedule or conditions,
and is presumably not enforceable.

# Things that are akin to DOSP in other fields or contexts

* Springing licenses by academic journals

Some academic journal publishers are applying springing licenses which
permit (at least) gratis public access to the full text of articles after a
fixed delay.  The delay is stated to protect the commercial interest of the
publisher by incentivizing organizations to pay for journal subscriptions.

The end license terms are not always akin to open source licenses, as
examples include CC-BY-NC and CC-BY-NC-ND.

The delay in this case is pre-announced and is apparently intended to be
legally binding, and may often form a part of the contract between the
publisher and the authors, based on the presumption that academic authors
prefer to allow less-restrictive access to their work.

* Government investments with time-limited exclusivity

# Other things that remind people of DOSP

* One-off decisions to relicense a proprietary project

Many of these have become very famous, but since there was no explicit
prior intention to make them open source, they don't really fit into
the DOSP concept.
